<?php $TRANSLATIONS = array(
"OpenID Changed" => "Đổi OpenID",
"Invalid request" => "Yêu cầu không hợp lệ",
"This is an OpenID server endpoint. For more information, see " => "Đây là một đầu cuối của OpenID .Để biết thêm thông tin, xem",
"Identity: <b>" => "Tình trạng: <b>",
"Realm: <b>" => "Lĩnh vực:<b>",
"User: <b>" => "Người dùng: <b>",
"Login" => "Đăng nhập",
"Error: <b>No user Selected" => "Lỗi: <b> Không có người dùng được chọn",
"OpenID" => "OpenID",
"you can authenticate to other sites with this address" => "bạn có thể xác thực đến các trang web khác với địa chỉ này",
"Authorized OpenID provider" => "Cung cấp OpenID",
"Your address at Wordpress, Identi.ca, &hellip;" => "Địa chỉ của bạn tại  Wordpress, Identi.ca, &hellip;"
);
